/* file_wrappers.h
 *
 * $Id: file_wrappers.h,v 1.3 2005/10/21 11:41:44 richardv Exp $
 *
 * Wiretap Library
 * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef __FILE_H__
#define __FILE_H__

#include "config.h"
#include <stdio.h>

typedef struct buffered_file buffered_file;

/* replacements for the fxxx functions of stdio, which add a layer of buffering
 * such that we can seek backwards in pipes. */

extern buffered_file *file_open(const char *path, const char *mode);
extern buffered_file *filed_open(int fd, const char *mode);
extern int file_close(buffered_file *fp);
extern int file_error(buffered_file *fh);
extern int file_eof(buffered_file *fh);

extern int file_getc(buffered_file *fp);
extern char *file_gets(char *s, int size, buffered_file *stream);

extern size_t file_read(void *ptr, size_t size, size_t nmemb, buffered_file *stream);

#if 0
/* this isn't used, and whilst there is an implementation in file-wrappers.c,
 * it hasn't been tested
 */
extern size_t file_write(void *ptr, size_t size, size_t nmemb, buffered_file *stream);
#endif


/* note that our implementations of seek and tell deal in off_t, which may be
 * longer than the long used by fseek and ftell.
 *
 * This should all work as well as possible in the presence of files of over
 * 2GB. Correct functionality in the face of such files requires support for
 * 64-bit off_ts in both stdio and, where present, zlib, but such details are
 * abstracted away by file_wrappers. You should always use off_t to hold your
 * file offsets, to give you maximum compatability with large files.
 *
 * If you use a 'long' instead, C's casting mechanism will do the best it can
 * for you, but failure *will* occur on files longer than 2GB.
 */
extern int file_seek(buffered_file *stream, off_t offset, int whence, int *err);
extern off_t file_tell(buffered_file *fp);



#endif /* __FILE_H__ */
